@@ -1,11 +1,13 @@
 import os
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
-import pygame
+
+os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 import numpy as np
+import pygame
 
 
 def manual_control(**kwargs):
     from .prison import env as _env
+
     env = _env(**kwargs)
     env.reset()
     clock = pygame.time.Clock()
@@ -13,7 +15,7 @@ def manual_control(**kwargs):
     y = 0
     prisoner_mapping = {}
     for prisoner in env.agents:
-        prisoner_mapping[env.infos[prisoner]['map_tuple']] = prisoner
+        prisoner_mapping[env.infos[prisoner]["map_tuple"]] = prisoner
     while True:
         clock.tick(30)
         agent_actions = {agent: 1 for agent in env.agents}
@@ -32,12 +34,10 @@ def manual_control(**kwargs):
                     y = min(3, y + 1)
                 elif event.key == pygame.K_j:
                     num_actions += 1
-                    agent_actions[prisoner_mapping[
-                        (x, y)]] = 0
+                    agent_actions[prisoner_mapping[(x, y)]] = 0
                 elif event.key == pygame.K_k:
                     num_actions += 1
-                    agent_actions[prisoner_mapping[
-                        (x, y)]] = 2
+                    agent_actions[prisoner_mapping[(x, y)]] = 2
                 elif event.key == pygame.K_ESCAPE:
                     test_done = True
         for i in env.agents:
