@@ -1,25 +1,25 @@
 import os
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
-import pygame as pg
-import pymunk as pm
-from pymunk import Vec2d
-from gym import spaces
-from gym.utils import seeding
-import numpy as np
-
-from pettingzoo import AECEnv
-from pettingzoo.utils import agent_selector
-from pettingzoo.utils import wrappers
-from . import constants as const
-from . import utils
-from .manual_control import manual_control
-from pettingzoo.utils.to_parallel import parallel_wrapper_fn
 
+os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
+import itertools as it
 import math
 import os
 from enum import IntEnum, auto
-import itertools as it
-from gym.utils import EzPickle
+
+import numpy as np
+import pygame as pg
+import pymunk as pm
+from gym import spaces
+from gym.utils import EzPickle, seeding
+from pymunk import Vec2d
+
+from pettingzoo import AECEnv
+from pettingzoo.utils import agent_selector, wrappers
+from pettingzoo.utils.conversions import parallel_wrapper_fn
+
+from . import constants as const
+from . import utils
+from .manual_control import manual_control
 
 
 class CollisionTypes(IntEnum):
@@ -217,7 +217,7 @@ class Fence(pg.sprite.Sprite):
         self.shape.collision_type = CollisionTypes.BOUNDARY
 
         self.body.position = utils.flipy(body_pos)
-        space.add(self.shape)
+        space.add(self.body, self.shape)
 
     def full_draw(self, screen):
         for rect in self.rects:
@@ -242,7 +242,7 @@ class Bank(pg.sprite.Sprite):
 
         self.body.position = utils.flipy(pos)
         self.space = space
-        self.space.add(self.shape, self.body)
+        self.space.add(self.body, self.shape)
 
     def convert_img(self):
         self.image = self.image.convert_alpha()
@@ -295,7 +295,7 @@ class Gold(pg.sprite.Sprite):
         self.image = self.image.convert_alpha()
 
 
-class Water(object):
+class Water:
     def __init__(self, pos, verts, space, rng):
         self.num_cols = math.ceil(const.SCREEN_WIDTH / const.TILE_SIZE)
         self.num_rows = math.ceil(const.WATER_HEIGHT / const.TILE_SIZE)
@@ -325,7 +325,7 @@ class Water(object):
 
         self.body.position = utils.flipy(pos)
         self.space = space
-        self.space.add(self.shape)
+        self.space.add(self.body, self.shape)
 
     def generate_debris(self, rng):
         self.debris = []
@@ -357,7 +357,7 @@ class Water(object):
         self.debris_tile = self.debris_tile.convert_alpha()
 
 
-class Background(object):
+class Background:
     def __init__(self, rng):
         self.num_cols = math.ceil(const.SCREEN_WIDTH / const.TILE_SIZE)
         self.num_rows = (
@@ -453,7 +453,7 @@ class raw_env(AECEnv, EzPickle):
         prospec_handoff_gold_reward=1,
         banker_receive_gold_reward=1,
         banker_deposit_gold_reward=1,
-        max_cycles=900,
+        max_cycles=450,
     ):
         EzPickle.__init__(
             self,
@@ -533,7 +533,10 @@ class raw_env(AECEnv, EzPickle):
             f = Fence(w_type, s_pos, b_pos, verts, self.space)
             self.fences.append(f)
 
-        self.metadata = {"render.modes": ["human", "rgb_array"], 'name': "prospector_v3"}
+        self.metadata = {
+            "render.modes": ["human", "rgb_array"],
+            "name": "prospector_v4",
+        }
 
         self.action_spaces = {}
         for p in self.prospectors:
@@ -561,6 +564,13 @@ class raw_env(AECEnv, EzPickle):
                 low=0, high=255, shape=const.BANKER_OBSERV_SHAPE, dtype=np.uint8
             )
 
+        self.state_space = spaces.Box(
+            low=0,
+            high=255,
+            shape=((const.SCREEN_HEIGHT, const.SCREEN_WIDTH, 3)),
+            dtype=np.uint8,
+        )
+
         self.possible_agents = self.agents[:]
         self._agent_selector = agent_selector(self.agents)
         self.agent_selection = self._agent_selector.next()
@@ -704,8 +714,9 @@ class raw_env(AECEnv, EzPickle):
         x, y = ag.center  # Calculated property added to prospector and banker classes
         sub_screen = np.array(
             capture[
-                max(0, x - delta): min(const.SCREEN_WIDTH, x + delta),
-                max(0, y - delta): min(const.SCREEN_HEIGHT, y + delta), :,
+                max(0, x - delta) : min(const.SCREEN_WIDTH, x + delta),
+                max(0, y - delta) : min(const.SCREEN_HEIGHT, y + delta),
+                :,
             ],
             dtype=np.uint8,
         )
@@ -739,6 +750,15 @@ class raw_env(AECEnv, EzPickle):
 
         return sub_screen
 
+    def state(self):
+        """
+        Returns an observation of the global environment
+        """
+        state = pg.surfarray.pixels3d(self.screen).copy()
+        state = np.rot90(state, k=3)
+        state = np.fliplr(state)
+        return state
+
     def step(self, action):
         if self.dones[self.agent_selection]:
             return self._was_done_step(action)
@@ -795,7 +815,6 @@ class raw_env(AECEnv, EzPickle):
         self.agent_selection = self._agent_selector.next()
         self._cumulative_rewards[agent_id] = 0
         self._accumulate_rewards()
-        self._dones_step_first()
 
     def reset(self):
         self.screen = pg.Surface(const.SCREEN_SIZE)
@@ -851,7 +870,7 @@ class raw_env(AECEnv, EzPickle):
             return transposed
 
     def full_draw(self):
-        """ Called to draw everything when first rendering """
+        """Called to draw everything when first rendering"""
         self.background.full_draw(self.screen)
         for f in self.fences:
             f.full_draw(self.screen)
@@ -859,7 +878,7 @@ class raw_env(AECEnv, EzPickle):
         self.all_sprites.draw(self.screen)
 
     def draw(self):
-        """ Called after each frame, all agents updated """
+        """Called after each frame, all agents updated"""
         self.background.draw(self.screen)
         for f in self.fences:
             f.full_draw(self.screen)
