@@ -1,12 +1,13 @@
-import itertools
 import copy
-import numpy as np
+import itertools
 import warnings
 
-from pettingzoo import AECEnv
+import numpy as np
 from gym import spaces
-from pettingzoo.utils.agent_selector import agent_selector
+
+from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
+from pettingzoo.utils.agent_selector import agent_selector
 
 
 def env():
@@ -20,7 +21,7 @@ def env():
 
 class raw_env(AECEnv):
 
-    metadata = {"render.modes": ["human"], "name": "checkers_v2"}
+    metadata = {"render.modes": ["human"], "name": "checkers_v3"}
 
     move64_32 = {
         1: 0,
@@ -64,14 +65,22 @@ class raw_env(AECEnv):
 
         self.ch = CheckersRules()
         num_agents = 2
-        self.agents = ["player_{}".format(i) for i in range(num_agents)]
+        self.agents = [f"player_{i}" for i in range(num_agents)]
         self.possible_agents = self.agents[:]
         self.agent_order = list(self.agents)
 
         self.action_spaces = {name: spaces.Discrete(64 * 4) for name in self.agents}
         self.observation_spaces = {
-            name: spaces.Dict({'observation': spaces.Box(low=0, high=1, shape=(8, 8, 4), dtype="float64"),
-                               'action_mask': spaces.Box(low=0, high=1, shape=(256,), dtype=np.int8)})
+            name: spaces.Dict(
+                {
+                    "observation": spaces.Box(
+                        low=0, high=1, shape=(8, 8, 4), dtype="float64"
+                    ),
+                    "action_mask": spaces.Box(
+                        low=0, high=1, shape=(256,), dtype=np.int8
+                    ),
+                }
+            )
             for name in self.agents
         }
         self.observation = np.zeros((8, 8, 4))
@@ -98,7 +107,7 @@ class raw_env(AECEnv):
         for i in legal_moves:
             action_mask[i] = 1
 
-        return {'observation': self.observation, 'action_mask': action_mask}
+        return {"observation": self.observation, "action_mask": action_mask}
 
     def reset(self):
         self.ch = CheckersRules()
