@@ -1,18 +1,21 @@
-from pettingzoo import AECEnv
-from gym import spaces
-import numpy as np
 import os
-import pygame
 
+import numpy as np
+import pygame
+from gym import spaces
+
+from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
 from pettingzoo.utils.agent_selector import agent_selector
 
 
 def get_image(path):
-    import pygame
     from os import path as os_path
+
+    import pygame
+
     cwd = os_path.dirname(__file__)
-    image = pygame.image.load(cwd + '/' + path)
+    image = pygame.image.load(cwd + "/" + path)
     sfc = pygame.Surface(image.get_size(), flags=pygame.SRCALPHA)
     sfc.blit(image, (0, 0))
     return sfc
@@ -27,7 +30,7 @@ def env():
 
 
 class raw_env(AECEnv):
-    metadata = {'render.modes': ['human', "rgb_array"], "name": "connect_four_v3"}
+    metadata = {"render.modes": ["human", "rgb_array"], "name": "connect_four_v3"}
 
     def __init__(self):
         super().__init__()
@@ -40,14 +43,21 @@ class raw_env(AECEnv):
 
         self.board = [0] * (6 * 7)
 
-        self.agents = ['player_0', 'player_1']
+        self.agents = ["player_0", "player_1"]
         self.possible_agents = self.agents[:]
 
         self.action_spaces = {i: spaces.Discrete(7) for i in self.agents}
-        self.observation_spaces = {i: spaces.Dict({
-            'observation': spaces.Box(low=0, high=1, shape=(6, 7, 2), dtype=np.int8),
-            'action_mask': spaces.Box(low=0, high=1, shape=(7,), dtype=np.int8)
-        }) for i in self.agents}
+        self.observation_spaces = {
+            i: spaces.Dict(
+                {
+                    "observation": spaces.Box(
+                        low=0, high=1, shape=(6, 7, 2), dtype=np.int8
+                    ),
+                    "action_mask": spaces.Box(low=0, high=1, shape=(7,), dtype=np.int8),
+                }
+            )
+            for i in self.agents
+        }
 
     # Key
     # ----
@@ -77,7 +87,7 @@ class raw_env(AECEnv):
         for i in legal_moves:
             action_mask[i] = 1
 
-        return {'observation': observation, 'action_mask': action_mask}
+        return {"observation": observation, "action_mask": action_mask}
 
     def _legal_moves(self):
         return [i for i in range(7) if self.board[i] == 0]
@@ -87,7 +97,7 @@ class raw_env(AECEnv):
         if self.dones[self.agent_selection]:
             return self._was_done_step(action)
         # assert valid move
-        assert (self.board[0:7][action] == 0), "played illegal move."
+        assert self.board[0:7][action] == 0, "played illegal move."
 
         piece = self.agents.index(self.agent_selection) + 1
         for i in list(filter(lambda x: x % 7 == action, list(range(41, -1, -1)))):
@@ -128,7 +138,7 @@ class raw_env(AECEnv):
 
         self.agent_selection = self._agent_selector.reset()
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         screen_width = 1287
         screen_height = 1118
         if self.screen is None:
@@ -143,34 +153,55 @@ class raw_env(AECEnv):
         # Load and scale all of the necessary images
         tile_size = (screen_width * (91 / 99)) / 7
 
-        red_chip = get_image(os.path.join('img', 'C4RedPiece.png'))
-        red_chip = pygame.transform.scale(red_chip, (int(tile_size * (9 / 13)), int(tile_size * (9 / 13))))
+        red_chip = get_image(os.path.join("img", "C4RedPiece.png"))
+        red_chip = pygame.transform.scale(
+            red_chip, (int(tile_size * (9 / 13)), int(tile_size * (9 / 13)))
+        )
 
-        black_chip = get_image(os.path.join('img', 'C4BlackPiece.png'))
-        black_chip = pygame.transform.scale(black_chip, (int(tile_size * (9 / 13)), int(tile_size * (9 / 13))))
+        black_chip = get_image(os.path.join("img", "C4BlackPiece.png"))
+        black_chip = pygame.transform.scale(
+            black_chip, (int(tile_size * (9 / 13)), int(tile_size * (9 / 13)))
+        )
 
-        board_img = get_image(os.path.join('img', 'Connect4Board.png'))
-        board_img = pygame.transform.scale(board_img, ((int(screen_width)), int(screen_height)))
+        board_img = get_image(os.path.join("img", "Connect4Board.png"))
+        board_img = pygame.transform.scale(
+            board_img, ((int(screen_width)), int(screen_height))
+        )
 
         self.screen.blit(board_img, (0, 0))
 
         # Blit the necessary chips and their positions
         for i in range(0, 42):
             if self.board[i] == 1:
-                self.screen.blit(red_chip, ((i % 7) * (tile_size) + (tile_size * (6 / 13)), int((i / 7)) * (tile_size) + (tile_size * (6 / 13))))
+                self.screen.blit(
+                    red_chip,
+                    (
+                        (i % 7) * (tile_size) + (tile_size * (6 / 13)),
+                        int(i / 7) * (tile_size) + (tile_size * (6 / 13)),
+                    ),
+                )
             elif self.board[i] == 2:
-                self.screen.blit(black_chip, ((i % 7) * (tile_size) + (tile_size * (6 / 13)), int((i / 7)) * (tile_size) + (tile_size * (6 / 13))))
+                self.screen.blit(
+                    black_chip,
+                    (
+                        (i % 7) * (tile_size) + (tile_size * (6 / 13)),
+                        int(i / 7) * (tile_size) + (tile_size * (6 / 13)),
+                    ),
+                )
 
         if mode == "human":
             pygame.display.update()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
 
-        return np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+        return (
+            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+        )
 
     def close(self):
         if self.screen is not None:
             import pygame
+
             pygame.quit()
             self.screen = None
 
@@ -184,25 +215,45 @@ class raw_env(AECEnv):
 
         for c in range(column_count - 3):
             for r in range(row_count):
-                if board[r][c] == piece and board[r][c + 1] == piece and board[r][c + 2] == piece and board[r][c + 3] == piece:
+                if (
+                    board[r][c] == piece
+                    and board[r][c + 1] == piece
+                    and board[r][c + 2] == piece
+                    and board[r][c + 3] == piece
+                ):
                     return True
 
         # Check vertical locations for win
         for c in range(column_count):
             for r in range(row_count - 3):
-                if board[r][c] == piece and board[r + 1][c] == piece and board[r + 2][c] == piece and board[r + 3][c] == piece:
+                if (
+                    board[r][c] == piece
+                    and board[r + 1][c] == piece
+                    and board[r + 2][c] == piece
+                    and board[r + 3][c] == piece
+                ):
                     return True
 
         # Check positively sloped diagonals
         for c in range(column_count - 3):
             for r in range(row_count - 3):
-                if board[r][c] == piece and board[r + 1][c + 1] == piece and board[r + 2][c + 2] == piece and board[r + 3][c + 3] == piece:
+                if (
+                    board[r][c] == piece
+                    and board[r + 1][c + 1] == piece
+                    and board[r + 2][c + 2] == piece
+                    and board[r + 3][c + 3] == piece
+                ):
                     return True
 
         # Check negatively sloped diagonals
         for c in range(column_count - 3):
             for r in range(3, row_count):
-                if board[r][c] == piece and board[r - 1][c + 1] == piece and board[r - 2][c + 2] == piece and board[r - 3][c + 3] == piece:
+                if (
+                    board[r][c] == piece
+                    and board[r - 1][c + 1] == piece
+                    and board[r - 2][c + 2] == piece
+                    and board[r - 3][c + 3] == piece
+                ):
                     return True
 
         return False
