@@ -1,17 +1,20 @@
-from pettingzoo import AECEnv
-from pettingzoo.utils.agent_selector import agent_selector
-from gym import spaces
 import random
+
+import numpy as np
 import rlcard
-from rlcard.utils.utils import print_card
+import rlcard.games.gin_rummy.utils.melding as melding
+from gym import spaces
+from gym.utils import EzPickle
 from rlcard.games.gin_rummy.player import GinRummyPlayer
 from rlcard.games.gin_rummy.utils import utils
-from rlcard.games.gin_rummy.utils.action_event import KnockAction, GinAction
-import rlcard.games.gin_rummy.utils.melding as melding
-import numpy as np
+from rlcard.games.gin_rummy.utils.action_event import GinAction, KnockAction
+from rlcard.utils.utils import print_card
+
+from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
+from pettingzoo.utils.agent_selector import agent_selector
+
 from .rlcard_base import RLCardBase
-from gym.utils import EzPickle
 
 
 def env(**kwargs):
@@ -25,9 +28,14 @@ def env(**kwargs):
 
 class raw_env(RLCardBase, EzPickle):
 
-    metadata = {'render.modes': ['human'], "name": "gin_rummy_v4"}
+    metadata = {"render.modes": ["human"], "name": "gin_rummy_v4"}
 
-    def __init__(self, knock_reward: float = 0.5, gin_reward: float = 1.0, opponents_hand_visible=False):
+    def __init__(
+        self,
+        knock_reward: float = 0.5,
+        gin_reward: float = 1.0,
+        opponents_hand_visible=False,
+    ):
         EzPickle.__init__(self, knock_reward, gin_reward)
         self._opponents_hand_visible = opponents_hand_visible
         num_planes = 5 if self._opponents_hand_visible else 4
@@ -40,9 +48,15 @@ class raw_env(RLCardBase, EzPickle):
     def _get_payoff(self, player: GinRummyPlayer, game) -> float:
         going_out_action = game.round.going_out_action
         going_out_player_id = game.round.going_out_player_id
-        if going_out_player_id == player.player_id and type(going_out_action) is KnockAction:
+        if (
+            going_out_player_id == player.player_id
+            and type(going_out_action) is KnockAction
+        ):
             payoff = self._knock_reward
-        elif going_out_player_id == player.player_id and type(going_out_action) is GinAction:
+        elif (
+            going_out_player_id == player.player_id
+            and type(going_out_action) is GinAction
+        ):
             payoff = self._gin_reward
         else:
             hand = player.hand
@@ -55,23 +69,23 @@ class raw_env(RLCardBase, EzPickle):
     def observe(self, agent):
         obs = self.env.get_state(self._name_to_int(agent))
         if self._opponents_hand_visible:
-            observation = obs['obs'].astype(self._dtype)
+            observation = obs["obs"].astype(self._dtype)
         else:
-            observation = obs['obs'][0:4, :].astype(self._dtype)
+            observation = obs["obs"][0:4, :].astype(self._dtype)
 
         legal_moves = self.next_legal_moves
         action_mask = np.zeros(110, int)
         for i in legal_moves:
             action_mask[i] = 1
 
-        return {'observation': observation, 'action_mask': action_mask}
+        return {"observation": observation, "action_mask": action_mask}
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         for player in self.possible_agents:
             state = self.env.game.round.players[self._name_to_int(player)].hand
-            print("\n===== {}'s Hand =====".format(player))
+            print(f"\n===== {player}'s Hand =====")
             print_card([c.__str__()[::-1] for c in state])
         state = self.env.game.get_state(0)
         print("\n==== Top Discarded Card ====")
-        print_card([c.__str__() for c in state['top_discard']] if state else None)
-        print('\n')
+        print_card([c.__str__() for c in state["top_discard"]] if state else None)
+        print("\n")
