@@ -1,11 +1,14 @@
-from pettingzoo import AECEnv
-from pettingzoo.utils.agent_selector import agent_selector
-from gym import spaces
-import rlcard
 import random
-from rlcard.utils.utils import print_card
+
 import numpy as np
+import rlcard
+from gym import spaces
+from rlcard.utils.utils import print_card
+
+from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
+from pettingzoo.utils.agent_selector import agent_selector
+
 from .rlcard_base import RLCardBase
 
 
@@ -20,17 +23,19 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {'render.modes': ['human'], "name": "leduc_holdem_v4"}
+    metadata = {"render.modes": ["human"], "name": "leduc_holdem_v4"}
 
     def __init__(self, num_players=2):
         super().__init__("leduc-holdem", num_players, (36,))
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         for player in self.possible_agents:
             state = self.env.game.get_state(self._name_to_int(player))
-            print("\n=============== {}'s Hand ===============".format(player))
-            print_card(state['hand'])
-            print("\n{}'s Chips: {}".format(player, state['my_chips']))
-        print('\n================= Public Cards =================')
-        print_card(state['public_card']) if state['public_card'] is not None else print('No public cards.')
-        print('\n')
+            print(f"\n=============== {player}'s Hand ===============")
+            print_card(state["hand"])
+            print("\n{}'s Chips: {}".format(player, state["my_chips"]))
+        print("\n================= Public Cards =================")
+        print_card(state["public_card"]) if state["public_card"] is not None else print(
+            "No public cards."
+        )
+        print("\n")
