@@ -1,10 +1,18 @@
 import numpy as np
-from .._mpe_utils.core import World, Agent, Landmark
+
+from .._mpe_utils.core import Agent, Landmark, World
 from .._mpe_utils.scenario import BaseScenario
 
 
 class Scenario(BaseScenario):
-    def make_world(self, num_good_agents=2, num_adversaries=4, num_landmarks=1, num_food=2, num_forests=2):
+    def make_world(
+        self,
+        num_good_agents=2,
+        num_adversaries=4,
+        num_landmarks=1,
+        num_food=2,
+        num_forests=2,
+    ):
         world = World()
         # set any world properties first
         world.dim_c = 4
@@ -23,7 +31,7 @@ class Scenario(BaseScenario):
             base_index = 0 if base_index < 0 else base_index
             base_name = "adversary" if agent.adversary else "agent"
             base_name = "leadadversary" if i == 0 else base_name
-            agent.name = '{}_{}'.format(base_name, base_index)
+            agent.name = f"{base_name}_{base_index}"
             agent.collide = True
             agent.leader = True if i == 0 else False
             agent.silent = True if i > 0 else False
@@ -34,21 +42,21 @@ class Scenario(BaseScenario):
         # add landmarks
         world.landmarks = [Landmark() for i in range(num_landmarks)]
         for i, landmark in enumerate(world.landmarks):
-            landmark.name = 'landmark %d' % i
+            landmark.name = "landmark %d" % i
             landmark.collide = True
             landmark.movable = False
             landmark.size = 0.2
             landmark.boundary = False
         world.food = [Landmark() for i in range(num_food)]
         for i, landmark in enumerate(world.food):
-            landmark.name = 'food %d' % i
+            landmark.name = "food %d" % i
             landmark.collide = False
             landmark.movable = False
             landmark.size = 0.03
             landmark.boundary = False
         world.forests = [Landmark() for i in range(num_forests)]
         for i, landmark in enumerate(world.forests):
-            landmark.name = 'forest %d' % i
+            landmark.name = "forest %d" % i
             landmark.collide = False
             landmark.movable = False
             landmark.size = 0.3
@@ -77,7 +85,7 @@ class Scenario(BaseScenario):
                 boundary_list.append(l)
 
         for i, l in enumerate(boundary_list):
-            l.name = 'boundary %d' % i
+            l.name = "boundary %d" % i
             l.collide = True
             l.movable = False
             l.boundary = True
@@ -90,8 +98,14 @@ class Scenario(BaseScenario):
     def reset_world(self, world, np_random):
         # random properties for agents
         for i, agent in enumerate(world.agents):
-            agent.color = np.array([0.45, 0.95, 0.45]) if not agent.adversary else np.array([0.95, 0.45, 0.45])
-            agent.color -= np.array([0.3, 0.3, 0.3]) if agent.leader else np.array([0, 0, 0])
+            agent.color = (
+                np.array([0.45, 0.95, 0.45])
+                if not agent.adversary
+                else np.array([0.95, 0.45, 0.45])
+            )
+            agent.color -= (
+                np.array([0.3, 0.3, 0.3]) if agent.leader else np.array([0, 0, 0])
+            )
             # random properties for landmarks
         for i, landmark in enumerate(world.landmarks):
             landmark.color = np.array([0.25, 0.25, 0.25])
@@ -141,11 +155,20 @@ class Scenario(BaseScenario):
     def reward(self, agent, world):
         # Agents are rewarded based on minimum agent distance to each landmark
         # boundary_reward = -10 if self.outside_boundary(agent) else 0
-        main_reward = self.adversary_reward(agent, world) if agent.adversary else self.agent_reward(agent, world)
+        main_reward = (
+            self.adversary_reward(agent, world)
+            if agent.adversary
+            else self.agent_reward(agent, world)
+        )
         return main_reward
 
     def outside_boundary(self, agent):
-        if agent.state.p_pos[0] > 1 or agent.state.p_pos[0] < -1 or agent.state.p_pos[1] > 1 or agent.state.p_pos[1] < -1:
+        if (
+            agent.state.p_pos[0] > 1
+            or agent.state.p_pos[0] < -1
+            or agent.state.p_pos[1] > 1
+            or agent.state.p_pos[1] < -1
+        ):
             return True
         else:
             return False
@@ -157,7 +180,9 @@ class Scenario(BaseScenario):
         adversaries = self.adversaries(world)
         if shape:
             for adv in adversaries:
-                rew += 0.1 * np.sqrt(np.sum(np.square(agent.state.p_pos - adv.state.p_pos)))
+                rew += 0.1 * np.sqrt(
+                    np.sum(np.square(agent.state.p_pos - adv.state.p_pos))
+                )
         if agent.collide:
             for a in adversaries:
                 if self.is_collision(a, agent):
@@ -177,7 +202,10 @@ class Scenario(BaseScenario):
         for food in world.food:
             if self.is_collision(agent, food):
                 rew += 2
-        rew -= 0.05 * min([np.sqrt(np.sum(np.square(food.state.p_pos - agent.state.p_pos))) for food in world.food])
+        rew -= 0.05 * min(
+            np.sqrt(np.sum(np.square(food.state.p_pos - agent.state.p_pos)))
+            for food in world.food
+        )
 
         return rew
 
@@ -188,7 +216,10 @@ class Scenario(BaseScenario):
         agents = self.good_agents(world)
         adversaries = self.adversaries(world)
         if shape:
-            rew -= 0.1 * min([np.sqrt(np.sum(np.square(a.state.p_pos - agent.state.p_pos))) for a in agents])
+            rew -= 0.1 * min(
+                np.sqrt(np.sum(np.square(a.state.p_pos - agent.state.p_pos)))
+                for a in agents
+            )
         if agent.collide:
             for ag in agents:
                 for adv in adversaries:
@@ -218,7 +249,13 @@ class Scenario(BaseScenario):
             other_pos.append(other.state.p_pos - agent.state.p_pos)
             if not other.adversary:
                 other_vel.append(other.state.p_vel)
-        return np.concatenate([agent.state.p_vel] + [agent.state.p_pos] + entity_pos + other_pos + other_vel)
+        return np.concatenate(
+            [agent.state.p_vel]
+            + [agent.state.p_pos]
+            + entity_pos
+            + other_pos
+            + other_vel
+        )
 
     def observation(self, agent, world):
         # get positions of all entities in this agent's reference frame
@@ -248,7 +285,10 @@ class Scenario(BaseScenario):
                 continue
             comm.append(other.state.c)
 
-            oth_f = [self.is_collision(other, world.forests[i]) for i in range(len(world.forests))]
+            oth_f = [
+                self.is_collision(other, world.forests[i])
+                for i in range(len(world.forests))
+            ]
 
             # without forest vis
             for i in range(len(world.forests)):
@@ -286,9 +326,31 @@ class Scenario(BaseScenario):
         comm = [world.agents[0].state.c]
 
         if agent.adversary and not agent.leader:
-            return np.concatenate([agent.state.p_vel] + [agent.state.p_pos] + entity_pos + other_pos + other_vel + in_forest + comm)
+            return np.concatenate(
+                [agent.state.p_vel]
+                + [agent.state.p_pos]
+                + entity_pos
+                + other_pos
+                + other_vel
+                + in_forest
+                + comm
+            )
         if agent.leader:
             return np.concatenate(
-                [agent.state.p_vel] + [agent.state.p_pos] + entity_pos + other_pos + other_vel + in_forest + comm)
+                [agent.state.p_vel]
+                + [agent.state.p_pos]
+                + entity_pos
+                + other_pos
+                + other_vel
+                + in_forest
+                + comm
+            )
         else:
-            return np.concatenate([agent.state.p_vel] + [agent.state.p_pos] + entity_pos + other_pos + in_forest + other_vel)
+            return np.concatenate(
+                [agent.state.p_vel]
+                + [agent.state.p_pos]
+                + entity_pos
+                + other_pos
+                + in_forest
+                + other_vel
+            )
