@@ -1,15 +1,18 @@
+from pettingzoo.utils.conversions import parallel_wrapper_fn
+
 from ._mpe_utils.simple_env import SimpleEnv, make_env
 from .scenarios.simple_reference import Scenario
-from pettingzoo.utils.conversions import parallel_wrapper_fn
 
 
 class raw_env(SimpleEnv):
     def __init__(self, local_ratio=0.5, max_cycles=25, continuous_actions=False):
-        assert 0. <= local_ratio <= 1., "local_ratio is a proportion. Must be between 0 and 1."
+        assert (
+            0.0 <= local_ratio <= 1.0
+        ), "local_ratio is a proportion. Must be between 0 and 1."
         scenario = Scenario()
         world = scenario.make_world()
         super().__init__(scenario, world, max_cycles, continuous_actions, local_ratio)
-        self.metadata['name'] = "simple_reference_v2"
+        self.metadata["name"] = "simple_reference_v2"
 
 
 env = make_env(raw_env)
