@@ -7,17 +7,15 @@ import numpy as np
 from gym import spaces
 from gym.utils import seeding
 
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
+os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 import pygame
 
-from .utils import agent_utils
+from .utils import agent_utils, two_d_maps
 from .utils.agent_layer import AgentLayer
 from .utils.controllers import RandomPolicy, SingleActionPolicy
-from .utils import two_d_maps
 
 
-class Pursuit():
-
+class Pursuit:
     def __init__(self, **kwargs):
         """
         In evade purusit a set of pursuers must 'tag' a set of evaders
@@ -42,18 +40,18 @@ class Pursuit():
         constraint_window: window in which agents can randomly spawn
         """
 
-        self.x_size = kwargs.pop('x_size', 16)
-        self.y_size = kwargs.pop('y_size', 16)
+        self.x_size = kwargs.pop("x_size", 16)
+        self.y_size = kwargs.pop("y_size", 16)
         x_size = self.x_size
         y_size = self.y_size
         self.map_matrix = two_d_maps.rectangle_map(self.x_size, self.y_size)
         self.max_cycles = kwargs.pop("max_cycles", 500)
         self.seed()
 
-        self.local_ratio = kwargs.pop('local_ratio', 1.0)
+        self.local_ratio = kwargs.pop("local_ratio", 1.0)
 
-        self.n_evaders = kwargs.pop('n_evaders', 30)
-        self.n_pursuers = kwargs.pop('n_pursuers', 8)
+        self.n_evaders = kwargs.pop("n_evaders", 30)
+        self.n_pursuers = kwargs.pop("n_pursuers", 8)
         self.num_agents = self.n_pursuers
 
         self.latest_reward_state = [0 for _ in range(self.num_agents)]
@@ -61,49 +59,59 @@ class Pursuit():
         self.latest_obs = [None for _ in range(self.num_agents)]
 
         # can see 7 grids around them by default
-        self.obs_range = kwargs.pop('obs_range', 7)
+        self.obs_range = kwargs.pop("obs_range", 7)
         # assert self.obs_range % 2 != 0, "obs_range should be odd"
         self.obs_offset = int((self.obs_range - 1) / 2)
         self.pursuers = agent_utils.create_agents(
-            self.n_pursuers, self.map_matrix, self.obs_range, self.np_random)
+            self.n_pursuers, self.map_matrix, self.obs_range, self.np_random
+        )
         self.evaders = agent_utils.create_agents(
-            self.n_evaders, self.map_matrix, self.obs_range, self.np_random)
+            self.n_evaders, self.map_matrix, self.obs_range, self.np_random
+        )
 
         self.pursuer_layer = AgentLayer(x_size, y_size, self.pursuers)
         self.evader_layer = AgentLayer(x_size, y_size, self.evaders)
 
-        self.n_catch = kwargs.pop('n_catch', 2)
+        self.n_catch = kwargs.pop("n_catch", 2)
 
         n_act_purs = self.pursuer_layer.get_nactions(0)
         n_act_ev = self.evader_layer.get_nactions(0)
 
-        self.freeze_evaders = kwargs.pop('freeze_evaders', False)
+        self.freeze_evaders = kwargs.pop("freeze_evaders", False)
 
         if self.freeze_evaders:
             self.evader_controller = kwargs.pop(
-                'evader_controller', SingleActionPolicy(4))
+                "evader_controller", SingleActionPolicy(4)
+            )
             self.pursuer_controller = kwargs.pop(
-                'pursuer_controller', SingleActionPolicy(4))
+                "pursuer_controller", SingleActionPolicy(4)
+            )
         else:
             self.evader_controller = kwargs.pop(
-                'evader_controller', RandomPolicy(n_act_purs, self.np_random))
+                "evader_controller", RandomPolicy(n_act_purs, self.np_random)
+            )
             self.pursuer_controller = kwargs.pop(
-                'pursuer_controller', RandomPolicy(n_act_ev, self.np_random))
+                "pursuer_controller", RandomPolicy(n_act_ev, self.np_random)
+            )
 
         self.current_agent_layer = np.zeros((x_size, y_size), dtype=np.int32)
 
-        self.tag_reward = kwargs.pop('tag_reward', 0.01)
+        self.tag_reward = kwargs.pop("tag_reward", 0.01)
 
-        self.catch_reward = kwargs.pop('catch_reward', 5.0)
+        self.catch_reward = kwargs.pop("catch_reward", 5.0)
 
-        self.urgency_reward = kwargs.pop('urgency_reward', 0.0)
+        self.urgency_reward = kwargs.pop("urgency_reward", 0.0)
 
         self.ally_actions = np.zeros(n_act_purs, dtype=np.int32)
         self.opponent_actions = np.zeros(n_act_ev, dtype=np.int32)
 
         max_agents_overlap = max(self.n_pursuers, self.n_evaders)
-        obs_space = spaces.Box(low=0, high=max_agents_overlap, shape=(
-            self.obs_range, self.obs_range, 3), dtype=np.float32)
+        obs_space = spaces.Box(
+            low=0,
+            high=max_agents_overlap,
+            shape=(self.obs_range, self.obs_range, 3),
+            dtype=np.float32,
+        )
         act_space = spaces.Discrete(n_act_purs)
         self.action_space = [act_space for _ in range(self.n_pursuers)]
 
@@ -112,20 +120,21 @@ class Pursuit():
 
         self.evaders_gone = np.array([False for i in range(self.n_evaders)])
 
-        self.surround = kwargs.pop('surround', True)
+        self.surround = kwargs.pop("surround", True)
 
-        self.constraint_window = kwargs.pop('constraint_window', 1.0)
+        self.constraint_window = kwargs.pop("constraint_window", 1.0)
 
         self.surround_mask = np.array([[-1, 0], [1, 0], [0, 1], [0, -1]])
 
-        self.model_state = np.zeros(
-            (4,) + self.map_matrix.shape, dtype=np.float32)
+        self.model_state = np.zeros((4,) + self.map_matrix.shape, dtype=np.float32)
         self.renderOn = False
         self.pixel_scale = 30
 
         self.frames = 0
         self.reset()
-        assert not kwargs, f"gave arguments {list(kwargs.keys())} that are not valid pursuit arguments"
+        assert (
+            not kwargs
+        ), f"gave arguments {list(kwargs.keys())} that are not valid pursuit arguments"
 
     def close(self):
         if self.renderOn:
@@ -163,16 +172,32 @@ class Pursuit():
 
         x_window_start = self.np_random.uniform(0.0, 1.0 - self.constraint_window)
         y_window_start = self.np_random.uniform(0.0, 1.0 - self.constraint_window)
-        xlb, xub = int(self.x_size * x_window_start), int(self.x_size * (x_window_start + self.constraint_window))
-        ylb, yub = int(self.y_size * y_window_start), int(self.y_size * (y_window_start + self.constraint_window))
+        xlb, xub = int(self.x_size * x_window_start), int(
+            self.x_size * (x_window_start + self.constraint_window)
+        )
+        ylb, yub = int(self.y_size * y_window_start), int(
+            self.y_size * (y_window_start + self.constraint_window)
+        )
         constraints = [[xlb, xub], [ylb, yub]]
 
-        self.pursuers = agent_utils.create_agents(self.n_pursuers, self.map_matrix, self.obs_range, self.np_random,
-                                                  randinit=True, constraints=constraints)
+        self.pursuers = agent_utils.create_agents(
+            self.n_pursuers,
+            self.map_matrix,
+            self.obs_range,
+            self.np_random,
+            randinit=True,
+            constraints=constraints,
+        )
         self.pursuer_layer = AgentLayer(self.x_size, self.y_size, self.pursuers)
 
-        self.evaders = agent_utils.create_agents(self.n_evaders, self.map_matrix, self.obs_range, self.np_random,
-                                                 randinit=True, constraints=constraints)
+        self.evaders = agent_utils.create_agents(
+            self.n_evaders,
+            self.map_matrix,
+            self.obs_range,
+            self.np_random,
+            randinit=True,
+            constraints=constraints,
+        )
         self.evader_layer = AgentLayer(self.x_size, self.y_size, self.evaders)
 
         self.latest_reward_state = [0 for _ in range(self.num_agents)]
@@ -216,7 +241,9 @@ class Pursuit():
         if is_last:
             global_val = self.latest_reward_state.mean()
             local_val = self.latest_reward_state
-            self.latest_reward_state = self.local_ratio * local_val + (1 - self.local_ratio) * global_val
+            self.latest_reward_state = (
+                self.local_ratio * local_val + (1 - self.local_ratio) * global_val
+            )
             self.frames = self.frames + 1
 
     def draw_model_state(self):
@@ -225,7 +252,11 @@ class Pursuit():
         for x in range(x_len):
             for y in range(y_len):
                 pos = pygame.Rect(
-                    self.pixel_scale * x, self.pixel_scale * y, self.pixel_scale, self.pixel_scale)
+                    self.pixel_scale * x,
+                    self.pixel_scale * y,
+                    self.pixel_scale,
+                    self.pixel_scale,
+                )
                 col = (0, 0, 0)
                 if self.model_state[0][x][y] == -1:
                     col = (255, 255, 255)
@@ -235,26 +266,36 @@ class Pursuit():
         for i in range(self.pursuer_layer.n_agents()):
             x, y = self.pursuer_layer.get_position(i)
             patch = pygame.Surface(
-                (self.pixel_scale * self.obs_range, self.pixel_scale * self.obs_range))
+                (self.pixel_scale * self.obs_range, self.pixel_scale * self.obs_range)
+            )
             patch.set_alpha(128)
             patch.fill((255, 152, 72))
             ofst = self.obs_range / 2.0
             self.screen.blit(
-                patch, (self.pixel_scale * (x - ofst + 1 / 2), self.pixel_scale * (y - ofst + 1 / 2)))
+                patch,
+                (
+                    self.pixel_scale * (x - ofst + 1 / 2),
+                    self.pixel_scale * (y - ofst + 1 / 2),
+                ),
+            )
 
     def draw_pursuers(self):
         for i in range(self.pursuer_layer.n_agents()):
             x, y = self.pursuer_layer.get_position(i)
-            center = (int(self.pixel_scale * x + self.pixel_scale / 2),
-                      int(self.pixel_scale * y + self.pixel_scale / 2))
+            center = (
+                int(self.pixel_scale * x + self.pixel_scale / 2),
+                int(self.pixel_scale * y + self.pixel_scale / 2),
+            )
             col = (255, 0, 0)
             pygame.draw.circle(self.screen, col, center, int(self.pixel_scale / 3))
 
     def draw_evaders(self):
         for i in range(self.evader_layer.n_agents()):
             x, y = self.evader_layer.get_position(i)
-            center = (int(self.pixel_scale * x + self.pixel_scale / 2),
-                      int(self.pixel_scale * y + self.pixel_scale / 2))
+            center = (
+                int(self.pixel_scale * x + self.pixel_scale / 2),
+                int(self.pixel_scale * y + self.pixel_scale / 2),
+            )
             col = (0, 0, 255)
 
             pygame.draw.circle(self.screen, col, center, int(self.pixel_scale / 3))
@@ -264,9 +305,12 @@ class Pursuit():
             if mode == "human":
                 pygame.display.init()
                 self.screen = pygame.display.set_mode(
-                    (self.pixel_scale * self.x_size, self.pixel_scale * self.y_size))
+                    (self.pixel_scale * self.x_size, self.pixel_scale * self.y_size)
+                )
             else:
-                self.screen = pygame.Surface((self.pixel_scale * self.x_size, self.pixel_scale * self.y_size))
+                self.screen = pygame.Surface(
+                    (self.pixel_scale * self.x_size, self.pixel_scale * self.y_size)
+                )
 
             self.renderOn = True
         self.draw_model_state()
@@ -281,11 +325,15 @@ class Pursuit():
         del observation
         if mode == "human":
             pygame.display.flip()
-        return np.transpose(new_observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+        return (
+            np.transpose(new_observation, axes=(1, 0, 2))
+            if mode == "rgb_array"
+            else None
+        )
 
     def animate(self, act_fn, nsteps, file_name, rate=1.5, verbose=False):
         """
-            Save an animation to an mp4 file.
+        Save an animation to an mp4 file.
         """
         # run sim loop
         o = self.reset()
@@ -299,12 +347,18 @@ class Pursuit():
             o, r, done, info = self.step(a)
             temp_name = join(file_path, "temp_" + str(i + 1) + ".png")
             self.save_image(temp_name)
-            removed += info['removed']
+            removed += info["removed"]
             if done:
                 break
         # use ffmpeg to create .pngs to .mp4 movie
-        ffmpeg_cmd = "ffmpeg -framerate " + str(rate) + " -i " + join(
-            file_path, "temp_%d.png") + " -c:v libx264 -pix_fmt yuv420p " + file_name
+        ffmpeg_cmd = (
+            "ffmpeg -framerate "
+            + str(rate)
+            + " -i "
+            + join(file_path, "temp_%d.png")
+            + " -c:v libx264 -pix_fmt yuv420p "
+            + file_name
+        )
         call(ffmpeg_cmd.split())
         # clean-up by removing .pngs
         map(os.remove, glob.glob(join(file_path, "temp_*.png")))
@@ -324,11 +378,23 @@ class Pursuit():
     def reward(self):
         es = self.evader_layer.get_state_matrix()  # evader positions
         rewards = [
-            self.tag_reward * np.sum(es[np.clip(
-                self.pursuer_layer.get_position(
-                    i)[0] + self.surround_mask[:, 0], 0, self.x_size - 1
-            ), np.clip(
-                self.pursuer_layer.get_position(i)[1] + self.surround_mask[:, 1], 0, self.y_size - 1)])
+            self.tag_reward
+            * np.sum(
+                es[
+                    np.clip(
+                        self.pursuer_layer.get_position(i)[0]
+                        + self.surround_mask[:, 0],
+                        0,
+                        self.x_size - 1,
+                    ),
+                    np.clip(
+                        self.pursuer_layer.get_position(i)[1]
+                        + self.surround_mask[:, 1],
+                        0,
+                        self.y_size - 1,
+                    ),
+                ]
+            )
             for i in range(self.n_pursuers)
         ]
         return np.array(rewards)
@@ -377,10 +443,15 @@ class Pursuit():
         xhd = x + self.obs_offset
         yld = y - self.obs_offset
         yhd = y + self.obs_offset
-        xlo, xhi, ylo, yhi = (np.clip(xld, 0, self.x_size - 1), np.clip(xhd, 0, self.x_size - 1),
-                              np.clip(yld, 0, self.y_size - 1), np.clip(yhd, 0, self.y_size - 1))
-        xolo, yolo = abs(np.clip(xld, -self.obs_offset, 0)
-                         ), abs(np.clip(yld, -self.obs_offset, 0))
+        xlo, xhi, ylo, yhi = (
+            np.clip(xld, 0, self.x_size - 1),
+            np.clip(xhd, 0, self.x_size - 1),
+            np.clip(yld, 0, self.y_size - 1),
+            np.clip(yhd, 0, self.y_size - 1),
+        )
+        xolo, yolo = abs(np.clip(xld, -self.obs_offset, 0)), abs(
+            np.clip(yld, -self.obs_offset, 0)
+        )
         xohi, yohi = xolo + (xhi - xlo), yolo + (yhi - ylo)
         return xlo, xhi + 1, ylo, yhi + 1, xolo, xohi + 1, yolo, yohi + 1
 
@@ -403,10 +474,13 @@ class Pursuit():
                 continue
             x, y = self.evader_layer.get_position(ai)
             if self.surround:
-                pos_that_catch = self.surround_mask + \
-                    self.evader_layer.get_position(ai)
+                pos_that_catch = self.surround_mask + self.evader_layer.get_position(ai)
                 truths = np.array(
-                    [np.equal([xi, yi], pos_that_catch).all(axis=1) for xi, yi in zip(xpur, ypur)])
+                    [
+                        np.equal([xi, yi], pos_that_catch).all(axis=1)
+                        for xi, yi in zip(xpur, ypur)
+                    ]
+                )
                 if np.sum(truths.any(axis=0)) == self.need_to_surround(x, y):
                     removed_evade.append(ai - rems)
                     self.evaders_gone[i] = True
@@ -414,8 +488,9 @@ class Pursuit():
                     tt = truths.any(axis=1)
                     for j in range(self.n_pursuers):
                         xpp, ypp = self.pursuer_layer.get_position(j)
-                        tes = np.concatenate(
-                            (xpur[tt], ypur[tt])).reshape(2, len(xpur[tt]))
+                        tes = np.concatenate((xpur[tt], ypur[tt])).reshape(
+                            2, len(xpur[tt])
+                        )
                         tem = tes.T == np.array([xpp, ypp])
                         if np.any(np.all(tem, axis=1)):
                             purs_sur[j] = True
@@ -446,8 +521,8 @@ class Pursuit():
 
     def need_to_surround(self, x, y):
         """
-            Compute the number of surrounding grid cells in x,y position that are open
-            (no wall or obstacle)
+        Compute the number of surrounding grid cells in x,y position that are open
+        (no wall or obstacle)
         """
         tosur = 4
         if x == 0 or x == (self.x_size - 1):
