@@ -1,8 +1,9 @@
-import warnings
-import random
-import numpy as np
 import hashlib
 import pickle
+import random
+import warnings
+
+import numpy as np
 
 
 def hash(val):
@@ -24,8 +25,8 @@ def calc_hash(new_env, rand_issue, max_env_iters):
             obs, rew, done, info = new_env.last()
             if done:
                 action = None
-            elif isinstance(obs, dict) and 'action_mask' in obs:
-                action = sampler.choice(np.flatnonzero(obs['action_mask']))
+            elif isinstance(obs, dict) and "action_mask" in obs:
+                action = sampler.choice(np.flatnonzero(obs["action_mask"]))
             else:
                 action = new_env.action_spaces[agent].sample()
             new_env.step(action)
@@ -41,11 +42,11 @@ def seed_action_spaces(env):
 
 
 def check_environment_deterministic(env1, env2, num_cycles):
-    '''
+    """
     env1 and env2 should be seeded environments
 
     returns a bool: true if env1 and env2 execute the same way
-    '''
+    """
 
     # seeds action space so that actions are deterministic
     seed_action_spaces(env1)
@@ -86,13 +87,15 @@ def test_environment_reset_deterministic(env1, num_cycles):
     assert hash1 == hash2, "environments kept state after seed(42) and reset()"
 
 
-def seed_test(env_constructor, num_cycles=10):
+def seed_test(env_constructor, num_cycles=10, test_kept_state=True):
     env1 = env_constructor()
-    test_environment_reset_deterministic(env1, num_cycles)
+    if test_kept_state:
+        test_environment_reset_deterministic(env1, num_cycles)
     env2 = env_constructor()
     base_seed = 42
     env1.seed(base_seed)
     env2.seed(base_seed)
 
-    assert check_environment_deterministic(env1, env2, num_cycles), \
-        ("The environment gives different results on multiple runs when intialized with the same seed. This is usually a sign that you are using np.random or random modules directly, which uses a global random state.")
+    assert check_environment_deterministic(
+        env1, env2, num_cycles
+    ), "The environment gives different results on multiple runs when initialized with the same seed. This is usually a sign that you are using np.random or random modules directly, which uses a global random state."
