@@ -5,7 +5,9 @@ class DeprecatedEnv(ImportError):
 class DeprecatedModule:
     def __init__(self, name, old_version, new_version):
         def env(*args, **kwargs):
-            raise DeprecatedEnv(f"{name}_{old_version} is now deprecated, use {name}_{new_version} instead")
+            raise DeprecatedEnv(
+                f"{name}_{old_version} is now deprecated, use {name}_{new_version} instead"
+            )
 
         self.env = env
         self.raw_env = env
