@@ -1,11 +1,12 @@
 import random
+
 import numpy as np
 
 
 def random_demo(env, render=True, episodes=1):
-    '''
+    """
     Runs an env object with random actions.
-    '''
+    """
 
     total_reward = 0
     done = False
@@ -21,8 +22,8 @@ def random_demo(env, render=True, episodes=1):
             total_reward += reward
             if done:
                 action = None
-            elif isinstance(obs, dict) and 'action_mask' in obs:
-                action = random.choice(np.flatnonzero(obs['action_mask']))
+            elif isinstance(obs, dict) and "action_mask" in obs:
+                action = random.choice(np.flatnonzero(obs["action_mask"]))
             else:
                 action = env.action_spaces[agent].sample()
             env.step(action)
